@@ -5,8 +5,10 @@ OC.L10N.register(
     "{name} (public)" : "{name} (publik)",
     "New conversation …" : "Ny konversation",
     "Participants" : "Deltagare",
+    "Projects" : "Projekt",
     "Chat" : "Chat",
     "Talk" : "Talk",
+    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtal med fler än 4 deltagare utan att en extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
     "Fullscreen (f)" : "Fullskärm (f)",
     "Copy" : "Kopiera",
@@ -26,15 +28,14 @@ OC.L10N.register(
     "Password" : "Lösenord",
     "Cancel" : "Avbryt",
     "Submit" : "Skicka",
-    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtal med fler än 4 deltagare utan att en extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
     "Leave call" : "Lämna samtalet",
     "Join call" : "Gå med i samtal",
     "Start call" : "Starta samtal",
     "Calls are disabled in this conversation." : "Samtal är inaktiverade i den här konversationen.",
+    "Go to file" : "Gå till fil",
     "Share link" : "Dela länk",
     "Change password" : "Byt lösenord",
     "Set password" : "Sätt lösenord",
-    "Go to file" : "Gå till fil",
     "Name" : "Namn",
     "Conversation name" : "Konversationens namn",
     "Rename" : "Byt namn",
@@ -133,6 +134,13 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} bjöd in dig till {call}",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du bjöds in för ett <strong>pratrum</strong> eller hade ett <strong>samtal</strong>",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Välkommen till Nextcloud Talk!\nI denna konversation kommer du att bli informerad om nya funktioner som finns i Nextcloud Talk.",
+    "New in Talk 6" : "Nytt i Talk 6",
+    "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
+    "* One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "* En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
+    "* You can now notify all participants by posting \"@all\" into the chat" : "* Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
+    "* With the \"arrow-up\" key you can repost your last message" : "* Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
+    "* Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "* Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
+    "* With projects you can create quick links between conversations, files and other items" : "* Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
     "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
     "The command does not exist" : "Kommandot finns inte",
     "Talk updates ✅" : "Talk uppdateringar ✅",
@@ -209,7 +217,7 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
     "Conversation not found" : "Konversationen hittades inte",
     "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
-    "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
+    "Chat, video & audio-conferencing using WebRTC" : "Chatt, video och ljud - konferenser med WebRTC",
     "None" : "Ingen",
     "User" : "Användare",
     "Everyone" : "Alla",
@@ -221,7 +229,7 @@ OC.L10N.register(
     "Delete this server" : "Ta bort denna server",
     "STUN server URL" : "STUN-server URL",
     "TURN server secret" : "TURN-server hemlighet",
-    "TURN server protocols" : "TURN server protokoll",
+    "TURN server protocols" : "TURN-server protokoll",
     "UDP and TCP" : "UDP och TCP",
     "UDP only" : "endast UDP",
     "TCP only" : "endast TCP",
@@ -241,6 +249,8 @@ OC.L10N.register(
     "Response to" : "Svar till",
     "Enabled for" : "Aktiverad för",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Kommandon är en ny beta-funktion i Nextcloud Talk. Det låter dig köra skript på din Nextcloud-server. Du kan definiera dem med vårt kommandoradsgränssnitt. Ett exempel på ett kalkylatorskript finns i vår <a {attributes}>dokumentation ↗</a>.",
+    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
+    "Select conversation" : "Välj konversation",
     "Signaling servers" : "Signalservrar",
     "Saved" : "Sparad",
     "Add a new server" : "Lägg till ny server",
@@ -250,18 +260,19 @@ OC.L10N.register(
     "Shared secret" : "Delad hemlighet",
     "STUN servers" : "STUN-servrar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
-    "TURN servers" : "TURN-servers",
+    "TURN servers" : "TURN-servrar",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
-    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
+    "This conversation is password-protected" : "Denna konversation är lösenordsskyddad",
     "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
     "Specify commands the users can use in chats" : "Ange kommandon som användare kan använda i chattar",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
-    "TURN server" : "TURN server",
+    "TURN server" : "TURN-server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
     "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
     "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
+    "Link to a conversation" : "Länk till en konversation",
     "Signaling server URL" : "Signalserver URL",
     "Delete server" : "Ta bort server",
     "Add new server" : "Lägg till ny server",
@@ -292,7 +303,9 @@ OC.L10N.register(
     "A group call has started" : "Ett gruppsamtal har startats",
     "{email} requested the password to access a share" : "{email} begärde lösenordet för att komma åt en delning",
     "Unnamed conversation" : "Namnlös konversation",
-    "Signaling server" : "Signalerar server",
+    "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
+    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
+    "Signaling server" : "Signalserver",
     "Join now" : "Anslut nu",
     "{user} sent a message in a conversation" : "{user} skickade ett meddelande i en konversation",
     "A deleted user sent a message in a conversation" : "En raderad användare skickade ett meddelande i en konversation",
